pub enum LClusterEntry {
Head(LClusterHead),
NonHead {
delta0: u16,
},
}Expand description
An entry describing a single logical cluster, which most often corresponds with a single logical, uncompressed block. These entries build a map for where to find the data in the compressed physical blocks.
Variants
Head(LClusterHead)
A head cluster. See LClusterHead.
NonHead
A nonhead cluster. These are blocks of data contained within the extent described by the most recent head lcluster.
Implementations
Sourceimpl LClusterEntry
impl LClusterEntry
Sourcepub fn read_full_entry(
reader: &dyn Reader,
offset: u64,
) -> Result<Self, ErofsError>
pub fn read_full_entry( reader: &dyn Reader, offset: u64, ) -> Result<Self, ErofsError>
Parse a single lcluster entry. This is for the CompressedFull data layout, for the
CompressedCompact data layout, see [read_compact_lcluster_entry].