pub enum Node {
Directory(DirectoryNode),
File(FileNode),
Symlink(SymlinkNode),
}Expand description
A node in the EROFS image.
Variants
Methods from Deref<Target = NodeInner>
Sourcepub fn compression_header(&self) -> Option<&CompressionHeader>
pub fn compression_header(&self) -> Option<&CompressionHeader>
Returns the compression header for this node, if it has a compressed data layout.
Sourcepub fn compact_entry_pos(
&self,
block_size: u64,
cluster_index: u64,
) -> Result<CompactEntry, ParsingError>
pub fn compact_entry_pos( &self, block_size: u64, cluster_index: u64, ) -> Result<CompactEntry, ParsingError>
Returns the position and layout of a compact logical cluster index entry.
Sourcepub fn index_end_offset(&self, block_size: u64) -> Result<u64, ParsingError>
pub fn index_end_offset(&self, block_size: u64) -> Result<u64, ParsingError>
Offset immediately following the logical cluster index table. For files with inline data, this is where the inline data is stored.
Sourcepub fn total_lclusters(&self, lcluster_size: u64) -> u64
pub fn total_lclusters(&self, lcluster_size: u64) -> u64
Returns the total number of logical clusters for this node.
pub fn size(&self) -> u64
pub fn ino(&self) -> u32
pub fn nid(&self) -> u64
pub fn link_count(&self) -> u32
pub fn uid(&self) -> u32
pub fn gid(&self) -> u32
pub fn mtime_ns(&self) -> u64
pub fn mode(&self) -> u16
Sourcepub fn storage_size(&self, block_size: u64) -> u64
pub fn storage_size(&self, block_size: u64) -> u64
Returns the storage size in bytes taken up by this node on disk.