Dirent

Struct Dirent 

#[repr(C)]
pub struct Dirent { pub nid: U64, pub nameoff: U16, pub file_type: u8, pub reserved: u8, }
Directory entry on-disk format. Contained within the directory data blocks.

Fields

nid: U64

Node number of the target inode for this entry.

nameoff: U16

Byte offset of the filename, relative to the start of this block. The name offset of the first dirent in a directory block indicates how many entries there are in that block.

file_type: u8

File type code.

reserved: u8

Reserved section.