#[repr(C)]pub struct InodeExtended {}Expand description
Extended inode on-disk format. Uses two inode slots. Allows for more metadata and also larger files.
Fields
format: U16Format information about this particular inode. Indicates if it is compact or extended, and the data layout (i.e. what i_u means for this node).
xattr_icount: U16Size of the inline xattr region, or zero if there are no xattrs. This is not a count of xattrs, it is plugged into a formula that determines the size in bytes of the xattr section.
mode: U16Standard unix file type and permission bits.
reserved_1: [u8; 2]Reserved section.
size: U64File size in bytes.
i_u: [u8; 4]Inode data union - the exact meaning of this field is dependent on the inode format field.
ino: U32Inode number for stat compatibility.
uid: U32Owner UID.
gid: U32Owner GID.
mtime: U64Last modification time in seconds since unix epoch.
mtime_ns: U32Nanosecond part of the last modification time.
link_count: U32Number of hard links.
reserved_2: [u8; 16]Reserved section.