#[repr(C)]pub struct LClusterIndex {
pub advisory_flags: U16,
pub extent_start_offset: U16,
pub data_union: [u8; 4],
}Expand description
Logical cluster index entry, for the legacy CompressedFull data layout. One of these exists per logical cluster in the inode data.
Fields
advisory_flags: U16Advisory bits (including cluster type).
extent_start_offset: U16If this logical cluster is a HEAD cluster, this holds the offset into the cluster where the data actually starts. The variable-length extents that map to physical clusters are not aligned in any meaningful way and can start in the middle of a logical cluster.
data_union: [u8; 4]Depending on if this logical cluster is a HEAD/PLAIN or NONHEAD type, this has two different interpretations -
- For HEAD and PLAIN types, this is the 4-byte block address for the physical cluster.
- For NONHEAD, this is two 2-byte values. [0] is the distance back to its HEAD lcluster, and [1] is the distance forward to the next HEAD lcluster.