#[repr(C)]pub struct XattrEntry {
pub name_len: u8,
pub name_index: u8,
pub value_size: U16,
}Expand description
Xattr entry record header. Describes an individual xattr key-value pair for this inode. The name suffix and value data immediately follow this header, padded to a 4-byte boundary.
Fields
name_len: u8Length in bytes of the name suffix (i.e. this length does not include the prefix section). The data is stored immediately following this entry.
name_index: u8Index of the attribute’s namespace prefix. There are 5 built-in prefixes -
- 1 -> “user.”
- 2 -> “system.posix_acl_access”
- 3 -> “system.posix_acl_default”
- 4 -> “trusted.”
- 6 -> “security.” If EROFS_FEATURE_INCOMPAT_XATTR_PREFIXES is set, this value is interpreted differently, but we don’t support that right now.
value_size: U16Length in bytes of the value that follows the name suffix after this header.