#[repr(C)]pub struct XattrInlineBodyHeader {
pub name_filter: U32,
pub shared_count: u8,
pub reserved: [u8; 7],
}Expand description
Inlined xattr body header. This sits immediately following the inode metadata if the xattr_icount is non-zero, providing information about the structure of the following xattr entries.
Fields
name_filter: U32If EROFS_FEATURE_COMPAT_XATTR_FILTER is enabled and supported, this is an inverted bloom filter on the xattr key, which can be used to determine if a key is either definitely absent (fast failure without reading/parsing) or may exist.
The number of 4 byte entries immediately after this header that are 32-bit indexes into the global shared xattr pool, located at the xattr_block_addr from the superblock. These shared xattrs dedupe identical key-value pairs across inodes to save space.
reserved: [u8; 7]Reserved section. Must be zero.