pub struct InodeFormat {
pub version: InodeVersion,
pub data_layout: InodeDataLayout,
}Expand description
The format of the inode, containing the version and data layout.
Fields
version: InodeVersiondata_layout: InodeDataLayoutImplementations
Sourceimpl InodeFormat
impl InodeFormat
Sourcepub fn parse(format: u16) -> Result<Self, ParsingError>
pub fn parse(format: u16) -> Result<Self, ParsingError>
Parse the inode format from the given format value.