LClusterHead

Struct LClusterHead 

pub struct LClusterHead {
    pub cluster_type: LClusterType,
    pub block_addr: u32,
    pub extent_start_offset: u16,
}
A head lcluster is one where the data for a particular extent starts. The logical data potentially starts at an unaligned address within this lcluster, described by [extent_start_offset].

Fields

cluster_type: LClusterType

The type of this cluster. Will be Head1, Head2, or Plain for this struct.

block_addr: u32

The physical block address where the data lives for the extent described by this set of entries.

extent_start_offset: u16

The offset into this lcluster where the data it is describing actually starts. Anything before this offset is actually from the previous extent, so when looking at these entries, if the requested read offset is before this start offset, the read logic needs to walk back one extent to find the relevant data.

Implementations

Source

impl LClusterHead

pub fn is_plain(&self) -> bool

pub fn logical_start( &self, cluster_index: u64, lcluster_size: u64, ) -> Option<u64>