InodeDataLayout

Enum InodeDataLayout 

pub enum InodeDataLayout {
    FlatPlain,
    FlatInline,
}
The layout of the data portion of the inode.

Variants



FlatPlain

The data union is interpreted as a block address. The data for this inode is stored in consecutive blocks starting from that block address.



FlatInline

The data union is interpreted as a block address. The data for this inode is stored in consecutive blocks starting from that block address, except for the tail of the data which is stored immediately following this metadata. If the whole tail is inlined, the data union is unused and doesn’t matter. For this to be used, the data must have a tail section that fits within the current metadata block.