#[repr(C)]pub struct CompressionMapHeader {
pub reserved_1: [u8; 2],
pub inline_data_size: U16,
pub advisory_flags: U16,
pub algorithm_type: u8,
pub lcluster_bits: u8,
}Expand description
Compression metadata header. For inodes with compressed data layouts, this header is written after the core metadata and extended attributes, padded to the next 8-byte boundary. It contains the compression info for this particular inode.
Fields
reserved_1: [u8; 2]Reserved 2 byte section. There are incompat features that change the interpretation of the first four bytes of this header but we don’t implement them, so this is always ignored today.
inline_data_size: U16If the advisory flags indicate there is an inline pcluster, this indicates the size of the inline data in bytes. This is gated behind an incompat flag that we don’t implement so it is not used in practice.
advisory_flags: U16Advisory flags for decompression.
algorithm_type: u8Compression algorithm types for logical clusters. We only support lz4 today so this should always be zero.
lcluster_bits: u8The first 4 bits of this are a modifier to the block size bits in the superblock. This allows files to have logical cluster sizes that are larger than the block size. The default is to match block size. We ignore this value right now and only default to block size.