InodeExtended

Struct InodeExtended 

#[repr(C)]
pub struct InodeExtended {
Show 13 fields pub format: U16, pub xattr_icount: U16, pub mode: U16, pub reserved_1: [u8; 2], pub size: U64, pub i_u: [u8; 4], pub ino: U32, pub uid: U32, pub gid: U32, pub mtime: U64, pub mtime_ns: U32, pub link_count: U32, pub reserved_2: [u8; 16],
}
Extended inode on-disk format. Uses two inode slots. Allows for more metadata and also larger files.

Fields

format: U16

Format information about this particular inode. Indicates if it is compact or extended, and the data layout (i.e. what i_u means for this node).

xattr_icount: U16

Size of the inline xattr region.

mode: U16

Standard unix file type and permission bits.

reserved_1: [u8; 2]

Reserved section.

size: U64

File size in bytes.

i_u: [u8; 4]

Inode data union - the exact meaning of this field is dependent on the inode format field.

ino: U32

Inode number for stat compatibility.

uid: U32

Owner UID.

gid: U32

Owner GID.

mtime: U64

Last modification time in seconds since unix epoch.

mtime_ns: U32

Nanosecond part of the last modification time.

link_count: U32

Number of hard links.

reserved_2: [u8; 16]

Reserved section.