#[repr(C)]pub struct SuperBlock {Show 19 fields
pub magic: U32,
pub checksum: U32,
pub feature_compat: U32,
pub block_size_bits: u8,
pub sb_ext_slots: u8,
pub root_nid: U16,
pub inode_count: U64,
pub epoch: U64,
pub fixed_nsec: U32,
pub blocks: U32,
pub meta_block_addr: U32,
pub xattr_block_addr: U32,
pub uuid: [u8; 16],
pub volume_name: [u8; 16],
pub feature_incompat: U32,
pub available_compr_algs: U16,
pub extra_devices: U32,
pub dirblkbits: u8,
pub reserved: [u8; 37],
}Expand description
The on-disk format of an erofs superblock.
Fields
magic: U32Magic number. Should be equal to EROFS_MAGIC.
checksum: U32CRC-32 checksum of the block containing the superblock. This field is set to zero in the checksummed version.
feature_compat: U32Feature flags. If any flags in here are not recognized the filesystem can still mount without a loss of correctness.
block_size_bits: u8Block size stored as a power of two.
sb_ext_slots: u8Number of 16-byte superblock extension slots.
root_nid: U16Node ID of the root directory.
inode_count: U64Total number of inodes - primarily for statfs. Can potentially be set to zero, don’t rely on it for validation.
epoch: U64UNIX timestamp of when the filesystem was created, used as mtime for compact inodes.
fixed_nsec: U32Fixed nanosecond timestamp used as mtime for compact inodes.
blocks: U32Total number of blocks - primarily for statfs. Can potentially be set to zero, don’t rely on it for validation.
meta_block_addr: U32Start block address of inode metadata zone. This is essentially an offset for node id calculations, not a guarantee that the inode data actually starts at this offset.
xattr_block_addr: U32Start block address of the xattr zone. Similar to meta_block_addr.
uuid: [u8; 16]128-bit UUID for this volume.
volume_name: [u8; 16]The volume name, zero-padded.
feature_incompat: U32Feature flags. If any flags here are not recognized, the filesystem can not be mounted.
available_compr_algs: U16Info about compression algorithms. Set to zero if image is not compressed.
extra_devices: U32External device support, ignored in core format.
dirblkbits: u8Set to zero in the core format. This can be used to make directory blocks larger than regular blocks (it modifies the block_size_bits field).
reserved: [u8; 37]There are some other fields we will care about when we implement xattr and compression support, but for now with the core format we don’t care about the rest of the superblock.