pub struct LClusterHead {
pub cluster_type: LClusterType,
pub block_addr: u32,
pub extent_start_offset: u16,
}Expand description
A head lcluster is one where the data for a particular extent starts. The logical data
potentially starts at an unaligned address within this lcluster, described by
[extent_start_offset].
Fields
cluster_type: LClusterTypeThe type of this cluster. Will be Head1, Head2, or Plain for this struct.
block_addr: u32The physical block address where the data lives for the extent described by this set of entries.
extent_start_offset: u16The offset into this lcluster where the data it is describing actually starts. Anything before this offset is actually from the previous extent, so when looking at these entries, if the requested read offset is before this start offset, the read logic needs to walk back one extent to find the relevant data.
Implementations